@@ -1,7 +1,9 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
 use serde::{Deserialize, Serialize};
 
+use crate::pipeline::name::ColumnName;
+
 use super::{column_constraint::ColumnConstraint, column_data_type::ColumnDataType};
 
 /// Column definition used in DDL.
@@ -16,6 +18,10 @@ impl ColumnDefinition {
         &self.column_data_type
     }
 
+    pub(crate) fn column_name(&self) -> &ColumnName {
+        self.column_data_type.column_name()
+    }
+
     pub(crate) fn column_constraints(&self) -> &[ColumnConstraint] {
         &self.column_constraints
     }
